tag

Function tag 

pub fn tag<E>(tag: &'static str) -> TagParser<E>
Like nom::bytes::complete::tag, except that we print what the tag was expecting if there was an error. I feel like this should be the default behavior TBH.