utf8_non_ascii

Function utf8_non_ascii 

pub fn utf8_non_ascii(input: Span<'_>) -> IResult<'_, Span<'_>, Span<'_>>
See the following RFCs:

The authoritative definition of UTF-8 is in [UNICODE]. This grammar is believed to describe the same thing Unicode describes, but does not claim to be authoritative. Implementors are urged to rely on the authoritative source, rather than on this ABNF.