pub struct ParseError<I: Debug> {
pub errors: Vec<(I, ParseErrorKind)>,
}Fields
errors: Vec<(I, ParseErrorKind)>Trait Implementations
Sourceimpl<I: Debug> ContextError<I> for ParseError<I>
impl<I: Debug> ContextError<I> for ParseError<I>
Sourcefn add_context(input: I, ctx: &'static str, other: Self) -> Self
fn add_context(input: I, ctx: &'static str, other: Self) -> Self
Creates a new error from an input position, a static string and an existing error.
This is used mainly in the [context] combinator, to add user friendly information
to errors when backtracking through a parse tree
Sourceimpl<I: Debug, E: Display> FromExternalError<I, E> for ParseError<I>
impl<I: Debug, E: Display> FromExternalError<I, E> for ParseError<I>
Sourcefn from_external_error(input: I, kind: ErrorKind, err: E) -> Self
fn from_external_error(input: I, kind: ErrorKind, err: E) -> Self
Creates a new error from an input position, an [ErrorKind] indicating the
wrapping parser, and an external error
Sourceimpl<I: Debug> ParseError<I> for ParseError<I>
impl<I: Debug> ParseError<I> for ParseError<I>
Sourcefn from_error_kind(input: I, kind: ErrorKind) -> Self
fn from_error_kind(input: I, kind: ErrorKind) -> Self
Creates an error from the input position and an [ErrorKind]
Sourcefn append(input: I, kind: ErrorKind, other: Self) -> Self
fn append(input: I, kind: ErrorKind, other: Self) -> Self
Combines an existing error with a new one created from the input
position and an [ErrorKind]. This is useful when backtracking
through a parse tree, accumulating error context on the way