pub fn utf8_non_ascii(input: Span<'_>) -> IResult<'_, Span<'_>, Span<'_>>Expand description
See the following RFCs:
- https://datatracker.ietf.org/doc/html/rfc6531#section-3.3
- https://datatracker.ietf.org/doc/html/rfc6532#section-3.1
- https://datatracker.ietf.org/doc/html/rfc3629#section-4 which define a bunch of ABNF, but then caps it off with:
The authoritative definition of UTF-8 is in [UNICODE]. This grammar is believed to describe the same thing Unicode describes, but does not claim to be authoritative. Implementors are urged to rely on the authoritative source, rather than on this ABNF.